/****************************************************************************
** $Id: kget_linkview.h 1246260 2011-08-10 22:19:39Z tpearson $
**
** Copyright (C) 2002 Carsten Pfeiffer <pfeiffer@kde.org>
**
****************************************************************************/

#ifndef KGET_LINKVIEW_H
#define KGET_LINKVIEW_H

#include <tqptrlist.h>

#include <klistview.h>
#include <kmainwindow.h>
#include <kurl.h>

#include "links.h"

class LinkViewItem : public TQListViewItem
{
public:
    LinkViewItem( TQListView *parent, const LinkItem * lnk );
    const LinkItem *link;
};


class KGetLinkView : public KMainWindow
{
    Q_OBJECT
  TQ_OBJECT

public:
    KGetLinkView( TQWidget *parent = 0L, const char *name = 0L );
    ~KGetLinkView();

    void setLinks( TQPtrList<LinkItem>& links );
    void setPageURL( const TQString& url );

signals:
    void leechURLs( const KURL::List& urls );

private slots:
    void slotStartLeech();
    void slotSelectAll();

private:
    void showLinks( const TQPtrList<LinkItem>& links );

    TQPtrList<LinkItem> m_links;

    KListView *m_view;

};

#endif // KGET_LINKVIEW_H
